@@ -21,10 +21,10 @@
 
 #include "config.h"
 
-#include "gnullsettingsbackend.h"
+#include "gsettingsbackendinternal.h"
+#include "giomodule.h"
 #include "gsimplepermission.h"
 
-#include "gioalias.h"
 
 #define G_TYPE_NULL_SETTINGS_BACKEND    (g_null_settings_backend_get_type ())
 #define G_NULL_SETTINGS_BACKEND(inst)   (G_TYPE_CHECK_INSTANCE_CAST ((inst), \
@@ -35,10 +35,11 @@
 typedef GSettingsBackendClass GNullSettingsBackendClass;
 typedef GSettingsBackend      GNullSettingsBackend;
 
-static GType g_null_settings_backend_get_type (void);
-G_DEFINE_TYPE (GNullSettingsBackend,
-               g_null_settings_backend,
-               G_TYPE_SETTINGS_BACKEND)
+G_DEFINE_TYPE_WITH_CODE (GNullSettingsBackend,
+                         g_null_settings_backend,
+                         G_TYPE_SETTINGS_BACKEND,
+                         g_io_extension_point_implement (G_SETTINGS_BACKEND_EXTENSION_POINT_NAME,
+                                                         g_define_type_id, "null", 10))
 
 static GVariant *
 g_null_settings_backend_read (GSettingsBackend   *backend,
@@ -59,7 +60,7 @@ g_null_settings_backend_write (GSettingsBackend *backend,
 }
 
 static gboolean
-g_null_settings_backend_write_keys (GSettingsBackend *backend,
+g_null_settings_backend_write_tree (GSettingsBackend *backend,
                                     GTree            *tree,
                                     gpointer          origin_tag)
 {
@@ -73,13 +74,6 @@ g_null_settings_backend_reset (GSettingsBackend *backend,
 {
 }
 
-static void
-g_null_settings_backend_reset_path (GSettingsBackend *backend,
-                                    const gchar      *path,
-                                    gpointer          origin_tag)
-{
-}
-
 static gboolean
 g_null_settings_backend_get_writable (GSettingsBackend *backend,
                                       const gchar      *name)
@@ -106,9 +100,8 @@ g_null_settings_backend_class_init (GNullSettingsBackendClass *class)
 
   backend_class->read = g_null_settings_backend_read;
   backend_class->write = g_null_settings_backend_write;
-  backend_class->write_keys = g_null_settings_backend_write_keys;
+  backend_class->write_tree = g_null_settings_backend_write_tree;
   backend_class->reset = g_null_settings_backend_reset;
-  backend_class->reset_path = g_null_settings_backend_reset_path;
   backend_class->get_writable = g_null_settings_backend_get_writable;
   backend_class->get_permission = g_null_settings_backend_get_permission;
 }
