@@ -54,11 +54,6 @@
 #include <unistd.h>
 #endif
 
-#ifndef G_OS_WIN32
-#include <sys/time.h>
-#include <time.h>
-#endif /* !G_OS_WIN32 */
-
 #include "gdatetime.h"
 
 #include "gatomic.h"
@@ -73,6 +68,11 @@
 
 #include "glibintl.h"
 
+#ifndef G_OS_WIN32
+#include <sys/time.h>
+#include <time.h>
+#endif /* !G_OS_WIN32 */
+
 /**
  * SECTION:date-time
  * @title: GDateTime
@@ -481,7 +481,7 @@ g_date_time_from_instant (GTimeZone *tz,
   GDateTime *datetime;
   gint64 offset;
 
-  if (instant < 0 || instant > 1000000000000000000)
+  if (instant < 0 || instant > G_GINT64_CONSTANT (1000000000000000000))
     return NULL;
 
   datetime = g_date_time_alloc (tz);
@@ -1409,7 +1409,7 @@ g_date_time_equal (gconstpointer dt1,
  * g_date_time_get_ymd:
  * @datetime: a #GDateTime.
  * @year: (out): the return location for the gregorian year, or %NULL.
- * @month: (out): the return location for the monty of the year, or %NULL.
+ * @month: (out): the return location for the month of the year, or %NULL.
  * @day: (out): the return location for the day of the month, or %NULL.
  *
  * Retrieves the Gregorian day, month, and year of a given #GDateTime.
@@ -1584,7 +1584,7 @@ g_date_time_get_day_of_month (GDateTime *datetime)
 /* Week of year / day of week getters {{{1 */
 /**
  * g_date_time_get_week_numbering_year:
- * @date: a #GDateTime
+ * @datetime: a #GDateTime
  *
  * Returns the ISO 8601 week-numbering year in which the week containing
  * @datetime falls.
